You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@harmony.apache.org by mc...@apache.org on 2008/05/27 16:06:23 UTC

svn commit: r660520 [2/3] - in /harmony/enhanced/drlvm/trunk/vm: em/src/ include/ include/open/ interpreter/src/ jitrino/src/codegenerator/ia32/ jitrino/src/dynopt/ jitrino/src/jet/ jitrino/src/optimizer/ jitrino/src/shared/ jitrino/src/translator/ jit...

Modified: harmony/enhanced/drlvm/trunk/vm/jitrino/src/translator/java/JavaByteCodeParser.cpp
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/jitrino/src/translator/java/JavaByteCodeParser.cpp?rev=660520&r1=660519&r2=660520&view=diff
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/jitrino/src/translator/java/JavaByteCodeParser.cpp (original)
+++ harmony/enhanced/drlvm/trunk/vm/jitrino/src/translator/java/JavaByteCodeParser.cpp Tue May 27 07:05:55 2008
@@ -286,19 +286,19 @@
 //
 // big-endian ordering
 //
-int16    si16(const uint8* bcp)    {
+int16    si16(const U_8* bcp)    {
     return (((int16)(bcp)[0] << 8) | bcp[1]);
 }
-uint16    su16(const uint8* bcp)    {
+uint16    su16(const U_8* bcp)    {
     return (((uint16)(bcp)[0] << 8)| bcp[1]);
 }
-I_32    si32(const uint8* bcp)    {
+I_32    si32(const U_8* bcp)    {
     return (((U_32)(bcp)[0] << 24) | 
             ((U_32)(bcp)[1] << 16) |
             ((U_32)(bcp)[2] << 8)  |
             bcp[3]);
 }
-uint64    si64(const uint8* bcp)    {
+uint64    si64(const U_8* bcp)    {
     return (((uint64)bcp[0] << 56) |
             ((uint64)bcp[1] << 48) |
             ((uint64)bcp[2] << 40) |
@@ -313,14 +313,14 @@
 //
 //
 bool 
-JavaByteCodeParserCallback::parseByteCode(const uint8* byteCodes,U_32 off) {
+JavaByteCodeParserCallback::parseByteCode(const U_8* byteCodes,U_32 off) {
     bool linearPassEnd = false;
     currentOffset = off;
-    const uint8* bcp = byteCodes + off;
+    const U_8* bcp = byteCodes + off;
 
     // find length of the byte code instruction
     U_32 len = 0; 
-    const uint8  opcode = *bcp;
+    const U_8  opcode = *bcp;
     assert (opcode <= 0xc9);
     if (Log::isEnabled()) {
         Log::out()<<"---------------------PARSING BYTECODE: "<<opcode_names[opcode]<<"        bc-offset="<<off<<std::endl;
@@ -526,79 +526,79 @@
     case 0x99:    
         ifeq(off+si16(bcp+1),off+3);        
         if (labelStack != NULL)
-            labelStack->push((uint8*)byteCodes + off+si16(bcp+1));
+            labelStack->push((U_8*)byteCodes + off+si16(bcp+1));
         break;
     case 0x9a:    
         ifne(off+si16(bcp+1),off+3);        
         if (labelStack != NULL)
-            labelStack->push((uint8*)byteCodes + off+si16(bcp+1));
+            labelStack->push((U_8*)byteCodes + off+si16(bcp+1));
         break;
     case 0x9b:    
         iflt(off+si16(bcp+1),off+3);
         if (labelStack != NULL)
-            labelStack->push((uint8*)byteCodes + off+si16(bcp+1));
+            labelStack->push((U_8*)byteCodes + off+si16(bcp+1));
         break;
     case 0x9c:    
         ifge(off+si16(bcp+1),off+3);
         if (labelStack != NULL)
-            labelStack->push((uint8*)byteCodes + off+si16(bcp+1));
+            labelStack->push((U_8*)byteCodes + off+si16(bcp+1));
         break;
     case 0x9d:    
         ifgt(off+si16(bcp+1),off+3);
         if (labelStack != NULL)
-            labelStack->push((uint8*)byteCodes + off+si16(bcp+1));
+            labelStack->push((U_8*)byteCodes + off+si16(bcp+1));
         break;
     case 0x9e:    
         ifle(off+si16(bcp+1),off+3);
         if (labelStack != NULL)
-            labelStack->push((uint8*)byteCodes + off+si16(bcp+1));
+            labelStack->push((U_8*)byteCodes + off+si16(bcp+1));
         break;
     case 0x9f:    
         if_icmpeq(off+si16(bcp+1),off+3);
         if (labelStack != NULL)
-            labelStack->push((uint8*)byteCodes + off+si16(bcp+1));
+            labelStack->push((U_8*)byteCodes + off+si16(bcp+1));
         break;
     // 0xa[0-f]    
     case 0xa0:    
         if_icmpne(off+si16(bcp+1),off+3);    
         if (labelStack != NULL)
-            labelStack->push((uint8*)byteCodes + off+si16(bcp+1));
+            labelStack->push((U_8*)byteCodes + off+si16(bcp+1));
         break;
     case 0xa1:    
         if_icmplt(off+si16(bcp+1),off+3);
         if (labelStack != NULL)
-            labelStack->push((uint8*)byteCodes + off+si16(bcp+1));
+            labelStack->push((U_8*)byteCodes + off+si16(bcp+1));
         break;
     case 0xa2:    
         if_icmpge(off+si16(bcp+1),off+3);
         if (labelStack != NULL)
-            labelStack->push((uint8*)byteCodes + off+si16(bcp+1));
+            labelStack->push((U_8*)byteCodes + off+si16(bcp+1));
         break;
     case 0xa3:
         if_icmpgt(off+si16(bcp+1),off+3);
         if (labelStack != NULL)
-            labelStack->push((uint8*)byteCodes + off+si16(bcp+1));
+            labelStack->push((U_8*)byteCodes + off+si16(bcp+1));
         break;
     case 0xa4:    
         if_icmple(off+si16(bcp+1),off+3);
         if (labelStack != NULL)
-            labelStack->push((uint8*)byteCodes + off+si16(bcp+1));
+            labelStack->push((U_8*)byteCodes + off+si16(bcp+1));
         break;
     case 0xa5:    
         if_acmpeq(off+si16(bcp+1),off+3);
         if (labelStack != NULL)
-            labelStack->push((uint8*)byteCodes + off+si16(bcp+1));
+            labelStack->push((U_8*)byteCodes + off+si16(bcp+1));
         break;
     case 0xa6:    
         if_acmpne(off+si16(bcp+1),off+3);
         if (labelStack != NULL)
-            labelStack->push((uint8*)byteCodes + off+si16(bcp+1));
+            labelStack->push((U_8*)byteCodes + off+si16(bcp+1));
         break;
     case 0xa7:    
         goto_(off+si16(bcp+1),off+3);
         linearPassEnd = true;
         if (labelStack != NULL)
-            labelStack->push((uint8*)byteCodes + off+si16(bcp+1));
+            labelStack->push((U_8*)byteCodes + off+si16(bcp+1));
         break;
     case 0xa8:    
         jsr(off+si16(bcp+1),off+3);
@@ -606,8 +606,8 @@
         if (labelStack != NULL) {
             // If labelStack is stack then the order of pushes should be reverted.
             // For now it is line. (labelStack is a Queue)
-            labelStack->push((uint8*)byteCodes + off+si16(bcp+1));
-            labelStack->push((uint8*)byteCodes + off+3);
+            labelStack->push((U_8*)byteCodes + off+si16(bcp+1));
+            labelStack->push((U_8*)byteCodes + off+3);
         }
         break;
     case 0xa9:    
@@ -622,9 +622,9 @@
         if (labelStack != NULL) {
             JavaSwitchTargetsIter switchIter2(bcp,off);
             while (switchIter2.hasNext()) {
-                labelStack->push((uint8*)byteCodes + switchIter2.getNextTarget());
+                labelStack->push((U_8*)byteCodes + switchIter2.getNextTarget());
             }
-            labelStack->push((uint8*)byteCodes + switchIter2.getDefaultTarget());
+            labelStack->push((U_8*)byteCodes + switchIter2.getDefaultTarget());
         }
         break;
     }
@@ -637,9 +637,9 @@
             JavaLookupSwitchTargetsIter switchIter2(bcp,off);
             while (switchIter2.hasNext()) {
                 U_32 key;
-                labelStack->push((uint8*)byteCodes + switchIter2.getNextTarget(&key));
+                labelStack->push((U_8*)byteCodes + switchIter2.getNextTarget(&key));
             }
-            labelStack->push((uint8*)byteCodes + switchIter2.getDefaultTarget());
+            labelStack->push((U_8*)byteCodes + switchIter2.getDefaultTarget());
         }
         break;
     }
@@ -694,18 +694,18 @@
     case 0xc6:    
         ifnull(off+si16(bcp+1),off+3);
         if (labelStack != NULL)
-            labelStack->push((uint8*)byteCodes + off+si16(bcp+1));
+            labelStack->push((U_8*)byteCodes + off+si16(bcp+1));
         break;
     case 0xc7:    
         ifnonnull(off+si16(bcp+1),off+3);
         if (labelStack != NULL)
-            labelStack->push((uint8*)byteCodes + off+si16(bcp+1));
+            labelStack->push((U_8*)byteCodes + off+si16(bcp+1));
         break;
     case 0xc8:    
         goto_(off+si32(bcp+1),off+5);
         linearPassEnd = true;
         if (labelStack != NULL)
-            labelStack->push((uint8*)byteCodes + off+si32(bcp+1));
+            labelStack->push((U_8*)byteCodes + off+si32(bcp+1));
         break;
     case 0xc9:    
         jsr(off+si32(bcp+1),off+5);
@@ -713,8 +713,8 @@
         if (labelStack != NULL) {
             // If labelStack is stack then the order of pushes should be reverted.
             // For now it is line. (labelStack is a Queue)
-            labelStack->push((uint8*)byteCodes + off+si32(bcp+1));
-            labelStack->push((uint8*)byteCodes + off+5);
+            labelStack->push((U_8*)byteCodes + off+si32(bcp+1));
+            labelStack->push((U_8*)byteCodes + off+5);
         }
         break;
     default:

Modified: harmony/enhanced/drlvm/trunk/vm/jitrino/src/translator/java/JavaByteCodeParser.h
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/jitrino/src/translator/java/JavaByteCodeParser.h?rev=660520&r1=660519&r2=660520&view=diff
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/jitrino/src/translator/java/JavaByteCodeParser.h (original)
+++ harmony/enhanced/drlvm/trunk/vm/jitrino/src/translator/java/JavaByteCodeParser.h Tue May 27 07:05:55 2008
@@ -37,10 +37,10 @@
 //
 // big-endian ordering
 //
-int16    si16(const uint8* bcp);
-uint16   su16(const uint8* bcp);
-I_32    si32(const uint8* bcp);
-uint64   si64(const uint8* bcp);
+int16    si16(const U_8* bcp);
+uint16   su16(const U_8* bcp);
+I_32    si32(const U_8* bcp);
+uint64   si64(const U_8* bcp);
 
 class JavaSwitchTargetsIter;
 class JavaLookupSwitchTargetsIter;
@@ -66,10 +66,10 @@
         visited = new (memManager) BitSet(memManager,byteCodeLength);
         bytecodevisited = new (memManager) BitSet(memManager,byteCodeLength);
         prepassVisited = NULL;
-        labelStack = new (memManager) Queue<uint8>(memManager);
+        labelStack = new (memManager) Queue<U_8>(memManager);
         noNeedToParse = false;
     }
-    bool parseByteCode(const uint8* byteCodes,U_32 byteCodeOffset);
+    bool parseByteCode(const U_8* byteCodes,U_32 byteCodeOffset);
     BitSet* getVisited()  { return visited; }
 protected:
     // the current byte codes offset
@@ -79,7 +79,7 @@
     BitSet*          visited;
     BitSet*          bytecodevisited;
     BitSet*          prepassVisited;
-    Queue<uint8>*    labelStack;
+    Queue<U_8>*    labelStack;
 
     // for example when some exception type can not be resolved
     bool noNeedToParse;
@@ -93,7 +93,7 @@
     virtual void lconst(int64) = 0;
     virtual void fconst(float) = 0;
     virtual void dconst(double) = 0;
-    virtual void bipush(int8) = 0;
+    virtual void bipush(I_8) = 0;
     virtual void sipush(int16) = 0;
     virtual void ldc(U_32) = 0;
     virtual void ldc2(U_32) = 0;
@@ -205,7 +205,7 @@
     virtual void if_acmpne(U_32 targetOffset,U_32 nextOffset) = 0;
     virtual void goto_(U_32 targetOffset,U_32 nextOffset) = 0;
     virtual void jsr(U_32 offset, U_32 nextOffset) = 0;
-    virtual void ret(uint16 varIndex, const uint8* byteCodes) = 0;
+    virtual void ret(uint16 varIndex, const U_8* byteCodes) = 0;
     virtual void tableswitch(JavaSwitchTargetsIter*) = 0;
     virtual void lookupswitch(JavaLookupSwitchTargetsIter*) = 0;
     virtual void ireturn(U_32 off) = 0;
@@ -223,15 +223,15 @@
     virtual void invokestatic(U_32 constPoolIndex) = 0;
     virtual void invokeinterface(U_32 constPoolIndex,U_32 count) = 0;
     virtual void new_(U_32 constPoolIndex) = 0;
-    virtual void newarray(uint8 type) = 0;
+    virtual void newarray(U_8 type) = 0;
     virtual void anewarray(U_32 constPoolIndex) = 0;
     virtual void arraylength() = 0;
     virtual void athrow() = 0;
     virtual void checkcast(U_32 constPoolIndex) = 0;
-    virtual int  instanceof(const uint8* bcp, U_32 constPoolIndex, U_32 off) = 0;
+    virtual int  instanceof(const U_8* bcp, U_32 constPoolIndex, U_32 off) = 0;
     virtual void monitorenter() = 0;
     virtual void monitorexit() = 0;
-    virtual void multianewarray(U_32 constPoolIndex,uint8 dimensions) = 0;
+    virtual void multianewarray(U_32 constPoolIndex,U_8 dimensions) = 0;
     virtual void ifnull(U_32 targetOffset,U_32 nextOffset) = 0;
     virtual void ifnonnull(U_32 targetOffset,U_32 nextOffset) = 0;
 
@@ -242,7 +242,7 @@
 
 class JavaSwitchTargetsIter {
 public:
-    JavaSwitchTargetsIter(const uint8* bcp,U_32 off) {
+    JavaSwitchTargetsIter(const U_8* bcp,U_32 off) {
         // skip over padding
         switchOffset = off;
         U_32 offset = ((off+4)&~3)-off;
@@ -271,8 +271,8 @@
     U_32         getHighValue()       {return highValue;}
     U_32         getLowValue()        {return lowValue;}
 private:
-    const uint8*   nextByteCode;
-    const uint8*   nextTarget;
+    const U_8*   nextByteCode;
+    const U_8*   nextTarget;
     U_32         switchOffset;
     U_32         numTargets;
     U_32         length;
@@ -283,7 +283,7 @@
 
 class JavaLookupSwitchTargetsIter {
 public:
-    JavaLookupSwitchTargetsIter(const uint8* bcp,U_32 off) {
+    JavaLookupSwitchTargetsIter(const U_8* bcp,U_32 off) {
         // skip over padding
         lookupOffset = off;
         U_32 offset = ((off+4)&~3)-off;
@@ -309,8 +309,8 @@
     U_32    getLength()            {return length;}
     U_32    getDefaultTarget()    {return defaultTarget+lookupOffset;}
 private:
-    const uint8*    nextByteCode;
-    const uint8*    nextTarget;
+    const U_8*    nextByteCode;
+    const U_8*    nextTarget;
     U_32          lookupOffset;
     U_32          numTargets;
     U_32          length;

Modified: harmony/enhanced/drlvm/trunk/vm/jitrino/src/translator/java/JavaByteCodeTranslator.cpp
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/jitrino/src/translator/java/JavaByteCodeTranslator.cpp?rev=660520&r1=660519&r2=660520&view=diff
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/jitrino/src/translator/java/JavaByteCodeTranslator.cpp (original)
+++ harmony/enhanced/drlvm/trunk/vm/jitrino/src/translator/java/JavaByteCodeTranslator.cpp Tue May 27 07:05:55 2008
@@ -596,7 +596,7 @@
     pushOpnd(irBuilder.genLdConstant(val));
 }
 void 
-JavaByteCodeTranslator::bipush(int8 val)  {
+JavaByteCodeTranslator::bipush(I_8 val)  {
     pushOpnd(irBuilder.genLdConstant((I_32)val));
 }
 void 
@@ -732,7 +732,7 @@
                 Opnd* constVal = NULL;
                 void* fieldAddr = field->getAddress();
                 switch(fieldType->tag) {
-                    case Type::Int8 :   constVal=irBuilder.genLdConstant(*(int8*)fieldAddr);break;
+                    case Type::Int8 :   constVal=irBuilder.genLdConstant(*(I_8*)fieldAddr);break;
                     case Type::Int16:   constVal=irBuilder.genLdConstant(*(int16*)fieldAddr);break;
                     case Type::Char :   constVal=irBuilder.genLdConstant(*(uint16*)fieldAddr);break;
                     case Type::Int32:   constVal=irBuilder.genLdConstant(*(I_32*)fieldAddr);break;
@@ -1311,7 +1311,7 @@
 }
 
 void 
-JavaByteCodeTranslator::ret(uint16 varIndex, const uint8* byteCodes) {
+JavaByteCodeTranslator::ret(uint16 varIndex, const U_8* byteCodes) {
     lastInstructionWasABranch = true;
     checkStack();
     irBuilder.genRet(getVarOpndLdVar(JavaLabelPrepass::RET,varIndex));
@@ -1726,7 +1726,7 @@
     }
 }
 void 
-JavaByteCodeTranslator::newarray(uint8 atype) {
+JavaByteCodeTranslator::newarray(U_8 atype) {
     NamedType* type = NULL;
     switch (atype) {
     case 4:    // boolean
@@ -1750,7 +1750,7 @@
     Opnd* arrayOpnd = irBuilder.genNewArray(type,popOpnd());
     pushOpnd(arrayOpnd);
     if (translationFlags.optArrayInit) {
-        const uint8* byteCodes = parser.getByteCodes();
+        const U_8* byteCodes = parser.getByteCodes();
         const U_32 byteCodeLength = parser.getByteCodeLength();
         U_32 offset = currentOffset + 2/*newarray length*/;
         U_32 length = checkForArrayInitializer(arrayOpnd, byteCodes, offset, byteCodeLength);
@@ -1774,7 +1774,7 @@
 }
 
 void 
-JavaByteCodeTranslator::multianewarray(U_32 constPoolIndex,uint8 dimensions) {
+JavaByteCodeTranslator::multianewarray(U_32 constPoolIndex,U_8 dimensions) {
     NamedType* arraytype = compilationInterface.getNamedType(methodToCompile.getParentHandle(), constPoolIndex);
     assert(arraytype->isArray());
     jitrino_assert(dimensions > 0);
@@ -1827,7 +1827,7 @@
 }
 
 int  
-JavaByteCodeTranslator::instanceof(const uint8* bcp, U_32 constPoolIndex, U_32 off)   {
+JavaByteCodeTranslator::instanceof(const U_8* bcp, U_32 constPoolIndex, U_32 off)   {
     NamedType *type = compilationInterface.getNamedType(methodToCompile.getParentHandle(), constPoolIndex);
     Opnd* src = popOpnd();
     Type* srcType = src->getType();
@@ -2478,22 +2478,22 @@
     }
 }
 
-U_32 JavaByteCodeTranslator::checkForArrayInitializer(Opnd* arrayOpnd, const uint8* byteCodes, U_32 offset, const U_32 byteCodeLength)
+U_32 JavaByteCodeTranslator::checkForArrayInitializer(Opnd* arrayOpnd, const U_8* byteCodes, U_32 offset, const U_32 byteCodeLength)
 {
     assert(offset < byteCodeLength);
     const U_32 MIN_NUMBER_OF_INIT_ELEMS = 2;
 
-    const uint8 BYTE_JAVA_SIZE    = 1;
-    const uint8 SHORT_JAVA_SIZE   = 2;
-    const uint8 INT_JAVA_SIZE     = 4;
-    const uint8 LONG_JAVA_SIZE    = 8;
+    const U_8 BYTE_JAVA_SIZE    = 1;
+    const U_8 SHORT_JAVA_SIZE   = 2;
+    const U_8 INT_JAVA_SIZE     = 4;
+    const U_8 LONG_JAVA_SIZE    = 8;
 
     // Skip short array initializers.
     // Average length of an array element initializer is 4.
     if ((byteCodeLength - offset)/4 < MIN_NUMBER_OF_INIT_ELEMS) return 0;
 
     // Size of the array elements
-    uint8 elem_size = 0;
+    U_8 elem_size = 0;
     // Number of initialized array elements
     U_32 elems = 0;
 
@@ -2580,12 +2580,12 @@
     if (elems < MIN_NUMBER_OF_INIT_ELEMS) return 0;
 
     const U_32 data_size = elems* elem_size;
-    uint8* init_array_data = new uint8[data_size];
+    U_8* init_array_data = new U_8[data_size];
 
     for (U_32 i = 0; i < elems; i++) {
         switch (elem_size) {
             case BYTE_JAVA_SIZE:
-                init_array_data[i] = (uint8)(array_data[i]);
+                init_array_data[i] = (U_8)(array_data[i]);
                 break;
             case SHORT_JAVA_SIZE:
                 *((uint16*)(init_array_data + (i * SHORT_JAVA_SIZE))) = (uint16)(array_data[i]);
@@ -2614,7 +2614,7 @@
     return predoff - offset;
 }
 
-U_32 JavaByteCodeTranslator::getNumericValue(const uint8* byteCodes, U_32 offset, const U_32 byteCodeLength, uint64& value) {
+U_32 JavaByteCodeTranslator::getNumericValue(const U_8* byteCodes, U_32 offset, const U_32 byteCodeLength, uint64& value) {
     assert(offset < byteCodeLength);
     U_32 off = offset;
     switch (byteCodes[off++]) {

Modified: harmony/enhanced/drlvm/trunk/vm/jitrino/src/translator/java/JavaByteCodeTranslator.h
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/jitrino/src/translator/java/JavaByteCodeTranslator.h?rev=660520&r1=660519&r2=660520&view=diff
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/jitrino/src/translator/java/JavaByteCodeTranslator.h (original)
+++ harmony/enhanced/drlvm/trunk/vm/jitrino/src/translator/java/JavaByteCodeTranslator.h Tue May 27 07:05:55 2008
@@ -77,7 +77,7 @@
     void lconst(int64 val);
     void fconst(float val);
     void dconst(double val);
-    void bipush(int8 val);
+    void bipush(I_8 val);
     void sipush(int16 val);
     void ldc(U_32 constPoolIndex);
     void ldc2(U_32 constPoolIndex);
@@ -189,7 +189,7 @@
     void if_acmpne(U_32 targetOffset,U_32 nextOffset);
     void goto_(U_32 targetOffset,U_32 nextOffset);
     void jsr(U_32 offset, U_32 nextOffset);
-    void ret(uint16 varIndex, const uint8* byteCodes);
+    void ret(uint16 varIndex, const U_8* byteCodes);
     void tableswitch(JavaSwitchTargetsIter*);
     void lookupswitch(JavaLookupSwitchTargetsIter*);
     void ireturn(U_32 off);
@@ -207,15 +207,15 @@
     void invokestatic(U_32 constPoolIndex);
     void invokeinterface(U_32 constPoolIndex,U_32 count);
     void new_(U_32 constPoolIndex);
-    void newarray(uint8 type);
+    void newarray(U_8 type);
     void anewarray(U_32 constPoolIndex);
     void arraylength();
     void athrow();
     void checkcast(U_32 constPoolIndex);
-    int  instanceof(const uint8* bcp, U_32 constPoolIndex, U_32 off) ;
+    int  instanceof(const U_8* bcp, U_32 constPoolIndex, U_32 off) ;
     void monitorenter();
     void monitorexit();
-    void multianewarray(U_32 constPoolIndex,uint8 dimensions);
+    void multianewarray(U_32 constPoolIndex,U_8 dimensions);
     void ifnull(U_32 targetOffset,U_32 nextOffset);
     void ifnonnull(U_32 targetOffset,U_32 nextOffset);
 private:
@@ -333,10 +333,10 @@
     // Method checks if following bytecodes are array initializers for newly created array.
     // If they are then substitute array initializers with jit helper array copy instruction.
     // Returns the length of bytecodes converted by this routine.
-    U_32 checkForArrayInitializer(Opnd* arrayOpnd, const uint8* byteCodes, U_32 offset, const U_32 byteCodeLength);
+    U_32 checkForArrayInitializer(Opnd* arrayOpnd, const U_8* byteCodes, U_32 offset, const U_32 byteCodeLength);
     // Obtain the next numeric value from the bytecode in array initialization sequence
     // Returns number of bytes read from the byteCodes array.
-    U_32 getNumericValue(const uint8* byteCodes, U_32 offset, const U_32 byteCodeLength, uint64& value);
+    U_32 getNumericValue(const U_8* byteCodes, U_32 offset, const U_32 byteCodeLength, uint64& value);
 
     //
     // private fields

Modified: harmony/enhanced/drlvm/trunk/vm/jitrino/src/translator/java/JavaLabelPrepass.cpp
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/jitrino/src/translator/java/JavaLabelPrepass.cpp?rev=660520&r1=660519&r2=660520&view=diff
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/jitrino/src/translator/java/JavaLabelPrepass.cpp (original)
+++ harmony/enhanced/drlvm/trunk/vm/jitrino/src/translator/java/JavaLabelPrepass.cpp Tue May 27 07:05:55 2008
@@ -994,7 +994,7 @@
 
     getVisited()->setBit(targetOffset,false);
 }
-void JavaLabelPrepass::ret(uint16 varIndex, const uint8* byteCodes) { 
+void JavaLabelPrepass::ret(uint16 varIndex, const U_8* byteCodes) { 
     StateInfo::SlotInfo *slot = &stateInfo.stack[varIndex];
     VariableIncarnation* var = slot->vars->getVarIncarnation();
     assert(var);
@@ -1022,7 +1022,7 @@
         //      to the instruction that follows the JSR
         //
         stateTable->setStateInfoFromFinally(&stateInfo, jsrNextOffset);
-        labelStack->push((uint8*)byteCodes + jsrNextOffset);
+        labelStack->push((U_8*)byteCodes + jsrNextOffset);
     }
 }
 
@@ -1057,7 +1057,7 @@
 void JavaLabelPrepass::lconst(int64 val)                   { pushType(int64Type); }
 void JavaLabelPrepass::fconst(float val)                   { pushType(singleType); }
 void JavaLabelPrepass::dconst(double val)                  { pushType(doubleType); }
-void JavaLabelPrepass::bipush(int8 val)                    { pushType(int32Type); }
+void JavaLabelPrepass::bipush(I_8 val)                    { pushType(int32Type); }
 void JavaLabelPrepass::sipush(int16 val)                   { pushType(int32Type); }
 
 void JavaLabelPrepass::iload(uint16 varIndex)              { genLoad(int32Type,varIndex); }
@@ -1161,7 +1161,7 @@
     pushType(slot);
 }
 
-void JavaLabelPrepass::newarray(uint8 etype)                { 
+void JavaLabelPrepass::newarray(U_8 etype)                { 
     popAndCheck(int32Type);
     NamedType *elemType = NULL;
     switch (etype) {
@@ -1220,7 +1220,7 @@
     pushType(type);
 }
 
-int JavaLabelPrepass::instanceof(const uint8* bcp, U_32 constPoolIndex, U_32 off)   {
+int JavaLabelPrepass::instanceof(const U_8* bcp, U_32 constPoolIndex, U_32 off)   {
     popType();
     pushType(int32Type);
     return 3;  // length of instanceof
@@ -1352,7 +1352,7 @@
         pseudoInvoke(methodSig_string);
     }
 }
-void JavaLabelPrepass::multianewarray(U_32 constPoolIndex,uint8 dimensions) {
+void JavaLabelPrepass::multianewarray(U_32 constPoolIndex,U_8 dimensions) {
     for (int i =0; i < dimensions; i++) {
         popAndCheck(int32Type);
     }

Modified: harmony/enhanced/drlvm/trunk/vm/jitrino/src/translator/java/JavaLabelPrepass.h
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/jitrino/src/translator/java/JavaLabelPrepass.h?rev=660520&r1=660519&r2=660520&view=diff
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/jitrino/src/translator/java/JavaLabelPrepass.h (original)
+++ harmony/enhanced/drlvm/trunk/vm/jitrino/src/translator/java/JavaLabelPrepass.h Tue May 27 07:05:55 2008
@@ -326,7 +326,7 @@
     void lconst(int64 val);
     void fconst(float val);
     void dconst(double val);
-    void bipush(int8 val);
+    void bipush(I_8 val);
     void sipush(int16 val);
     void ldc(U_32 constPoolIndex);
     void ldc2(U_32 constPoolIndex);
@@ -438,7 +438,7 @@
     void if_acmpne(U_32 targetOffset,U_32 nextOffset);
     void goto_(U_32 targetOffset,U_32 nextOffset);
     void jsr(U_32 offset, U_32 nextOffset);
-    void ret(uint16 varIndex, const uint8* byteCodes);
+    void ret(uint16 varIndex, const U_8* byteCodes);
     void tableswitch(JavaSwitchTargetsIter*);
     void lookupswitch(JavaLookupSwitchTargetsIter*);
     void incrementReturn();
@@ -457,22 +457,22 @@
     void invokestatic(U_32 constPoolIndex) ;
     void invokeinterface(U_32 constPoolIndex,U_32 count) ;
     void new_(U_32 constPoolIndex) ;
-    void newarray(uint8 type) ;
+    void newarray(U_8 type) ;
     void anewarray(U_32 constPoolIndex) ;
     void arraylength() ;
     void athrow() ;
     void checkcast(U_32 constPoolIndex) ;
-    int  instanceof(const uint8* bcp, U_32 constPoolIndex, U_32 off) ;
+    int  instanceof(const U_8* bcp, U_32 constPoolIndex, U_32 off) ;
     void monitorenter() ;
     void monitorexit() ;
-    void multianewarray(U_32 constPoolIndex,uint8 dimensions) ;
+    void multianewarray(U_32 constPoolIndex,U_8 dimensions) ;
     void ifnull(U_32 targetOffset,U_32 nextOffset);
     void ifnonnull(U_32 targetOffset,U_32 nextOffset);
     void pushCatchLabel(U_32 offset) {
-        labelStack->push((uint8*)methodDesc.getByteCodes()+offset);
+        labelStack->push((U_8*)methodDesc.getByteCodes()+offset);
     }
     void pushRestart(U_32 offset) {
-        labelStack->push((uint8*)methodDesc.getByteCodes()+offset);
+        labelStack->push((U_8*)methodDesc.getByteCodes()+offset);
     }
 private:
     friend class JavaExceptionParser;

Modified: harmony/enhanced/drlvm/trunk/vm/jitrino/src/translator/java/JavaTranslator.cpp
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/jitrino/src/translator/java/JavaTranslator.cpp?rev=660520&r1=660519&r2=660520&view=diff
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/jitrino/src/translator/java/JavaTranslator.cpp (original)
+++ harmony/enhanced/drlvm/trunk/vm/jitrino/src/translator/java/JavaTranslator.cpp Tue May 27 07:05:55 2008
@@ -42,7 +42,7 @@
 
     JavaFlowGraphBuilder cfgBuilder(irBuilder.getInstFactory()->getMemManager(),irBuilder);
 
-    ByteCodeParser parser((const uint8*)byteCodes,byteCodeSize);
+    ByteCodeParser parser((const U_8*)byteCodes,byteCodeSize);
     // generate code
     JavaByteCodeTranslator translator(ci,
                               translatorMemManager,

Modified: harmony/enhanced/drlvm/trunk/vm/port/include/port_atomic.h
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/port/include/port_atomic.h?rev=660520&r1=660519&r2=660520&view=diff
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/port/src/atomic/linux_ipf/port_atomic_asm.asm (original)
+++ harmony/enhanced/drlvm/trunk/vm/port/src/atomic/linux_ipf/port_atomic_asm.asm Tue May 27 07:05:55 2008
@@ -22,7 +22,7 @@
 	.global port_atomic_cas8#
 	.align 32
 port_atomic_cas8:
-	// r32 -- Destination (uint8 *)
+	// r32 -- Destination (U_8 *)
 	// r33 -- Exchange
 	// r34 -- Comperand
 	// r35 -- for save ar.pfs

Modified: harmony/enhanced/drlvm/trunk/vm/port/src/atomic/win/port_atomic_em64t.asm
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/port/src/atomic/win/port_atomic_em64t.asm?rev=660520&r1=660519&r2=660520&view=diff
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/port/src/atomic/win/port_atomic_em64t.asm (original)
+++ harmony/enhanced/drlvm/trunk/vm/port/src/atomic/win/port_atomic_em64t.asm Tue May 27 07:05:55 2008
@@ -4,7 +4,7 @@
 
 port_atomic_cas8 PROC
 
-;uint8 port_atomic_cas8(volatile uint8 * data , uint8 value, uint8 comp)
+;U_8 port_atomic_cas8(volatile U_8 * data , U_8 value, U_8 comp)
 ;
 ;    rcx - *data - pointer to the byte which shoud be exchanged
 ;    rdx - value - new value

Modified: harmony/enhanced/drlvm/trunk/vm/port/src/encoder/ia32_em64t/encoder.h
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/port/src/encoder/ia32_em64t/encoder.h?rev=660520&r1=660519&r2=660520&view=diff
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/port/src/encoder/ia32_em64t/encoder.h (original)
+++ harmony/enhanced/drlvm/trunk/vm/port/src/encoder/ia32_em64t/encoder.h Tue May 27 07:05:55 2008
@@ -244,7 +244,7 @@
 #ifndef NDEBUG
         switch (size) {
         case size_8:
-            assert(val == (int64)(int8)val);
+            assert(val == (int64)(I_8)val);
             break;
         case size_16:
             assert(val == (int64)(int16)val);
@@ -269,7 +269,7 @@
 #ifndef NDEBUG
         switch (size) {
         case size_8:
-            assert((I_32)val == (I_32)(int8)val);
+            assert((I_32)val == (I_32)(I_8)val);
             break;
         case size_16:
             assert((I_32)val == (I_32)(int16)val);

Modified: harmony/enhanced/drlvm/trunk/vm/vmcore/include/bytereader.h
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/vmcore/include/bytereader.h?rev=660520&r1=660519&r2=660520&view=diff
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/vmcore/include/bytereader.h (original)
+++ harmony/enhanced/drlvm/trunk/vm/vmcore/include/bytereader.h Tue May 27 07:05:55 2008
@@ -29,13 +29,13 @@
 {
     unsigned offset;
     unsigned len;
-    const uint8* bytebuffer;
-    const uint8* start;
-    const uint8* end;
-    const uint8* curr;
+    const U_8* bytebuffer;
+    const U_8* start;
+    const U_8* end;
+    const U_8* curr;
     bool byte_array_owner;
 public:
-    ByteReader(const uint8* bytecode, unsigned _offset, unsigned _len)
+    ByteReader(const U_8* bytecode, unsigned _offset, unsigned _len)
         : offset(_offset), len(_len), bytebuffer(bytecode),
           start(bytecode + offset), end(start + len),
           curr(bytecode + offset), byte_array_owner(false) {}
@@ -86,7 +86,7 @@
 
         U_32 result = 0;
         curr += 4;
-        const uint8* curr_byte = curr;
+        const U_8* curr_byte = curr;
         for (int i = 0; i < 4; i++) {
             U_32 x = (U_32) * (--curr_byte);
             result = (result << 8) + x;
@@ -114,7 +114,7 @@
 
         uint16 result = 0;
         curr += 2;
-        const uint8* curr_byte = curr;
+        const U_8* curr_byte = curr;
         for (int i = 0; i < 2; i++) {
             uint16 x = (uint16) * (--curr_byte);
             result = (uint16) ((result << 8) + x);
@@ -123,7 +123,7 @@
         return true;
     } // parse_u2_le
 
-    bool parse_u1(uint8 * val)
+    bool parse_u1(U_8 * val)
     {
         if(!have(1)) return false;
 
@@ -131,8 +131,8 @@
         return true;
     } // parse_u1
 
-    const uint8* get_and_skip(unsigned len) {
-        const uint8* _curr = curr;
+    const U_8* get_and_skip(unsigned len) {
+        const U_8* _curr = curr;
         if(!skip(len)) return NULL;
         return _curr;
     } // get_and_skip

Modified: harmony/enhanced/drlvm/trunk/vm/vmcore/include/class_member.h
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/vmcore/include/class_member.h?rev=660520&r1=660519&r2=660520&view=diff
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/vmcore/include/class_member.h (original)
+++ harmony/enhanced/drlvm/trunk/vm/vmcore/include/class_member.h Tue May 27 07:05:55 2008
@@ -658,9 +658,9 @@
     AnnotationValue * get_default_value() {return _default_value; }
 
 private:
-    uint8 _num_param_annotations;
+    U_8 _num_param_annotations;
     AnnotationTable ** _param_annotations;
-    uint8 _num_invisible_param_annotations;
+    U_8 _num_invisible_param_annotations;
     AnnotationTable ** _invisible_param_annotations; 
     
     AnnotationValue * _default_value;
@@ -800,9 +800,9 @@
     }
 
 
-    uint8* m_stackmap;
+    U_8* m_stackmap;
 public:
-    uint8* get_stackmap() {
+    U_8* get_stackmap() {
         return m_stackmap;
     }
 

Modified: harmony/enhanced/drlvm/trunk/vm/vmcore/include/classloader.h
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/vmcore/include/classloader.h?rev=660520&r1=660519&r2=660520&view=diff
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/vmcore/include/classloader.h (original)
+++ harmony/enhanced/drlvm/trunk/vm/vmcore/include/classloader.h Tue May 27 07:05:55 2008
@@ -186,7 +186,7 @@
     Class* NewClass(const Global_Env* env, const String* name);
     Package* ProvidePackage(Global_Env* env, const String *class_name, const char *jar);
     Class* DefineClass(Global_Env* env, const char* class_name,
-        uint8* bytecode, unsigned offset, unsigned length, const String** res_name = NULL);
+        U_8* bytecode, unsigned offset, unsigned length, const String** res_name = NULL);
     Class* LoadClass( Global_Env* UNREF env, const String* UNREF name);
     Class* LoadVerifyAndPrepareClass( Global_Env* env, const String* name);
     virtual void ReportException(const char* exn_name, std::stringstream& message_stream);

Modified: harmony/enhanced/drlvm/trunk/vm/vmcore/include/exceptions_jit.h
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/vmcore/include/exceptions_jit.h?rev=660520&r1=660519&r2=660520&view=diff
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/vmcore/include/exceptions_jit.h (original)
+++ harmony/enhanced/drlvm/trunk/vm/vmcore/include/exceptions_jit.h Tue May 27 07:05:55 2008
@@ -28,7 +28,7 @@
 
 //**** Main exception propogation entry points
 void exn_throw_for_JIT(ManagedObject* exn_obj, Class_Handle exn_class,
-    Method_Handle exn_constr, uint8* jit_exn_constr_args, jvalue* vm_exn_constr_args);
+    Method_Handle exn_constr, U_8* jit_exn_constr_args, jvalue* vm_exn_constr_args);
 
 // Throw an exception in the current thread.
 // Must be called with an M2nFrame on the top of the stack, and throws to the previous managed
@@ -36,7 +36,7 @@
 // If exn_obj is nonnull then it is the exception, otherwise the exception is an instance of
 // exn_class created using the given constructor and arguments (a null exn_constr indicates the default constructor).
 // Does not return.
-void exn_athrow(ManagedObject* exn_obj, Class_Handle exn_class, Method_Handle exn_constr=NULL, uint8* exn_constr_args=NULL);
+void exn_athrow(ManagedObject* exn_obj, Class_Handle exn_class, Method_Handle exn_constr=NULL, U_8* exn_constr_args=NULL);
 
 // Throw an exception in the current thread.
 // Must be called with the current thread "suspended" in managed code and regs holds the suspended values.

Modified: harmony/enhanced/drlvm/trunk/vm/vmcore/include/heap.h
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/vmcore/include/heap.h?rev=660520&r1=660519&r2=660520&view=diff
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/vmcore/include/heap.h (original)
+++ harmony/enhanced/drlvm/trunk/vm/vmcore/include/heap.h Tue May 27 07:05:55 2008
@@ -184,6 +184,6 @@
  * @note XXX exception and out of memory semantics are not specified -salikh
  */
 ManagedObject *class_alloc_new_object_and_run_constructor(
-    Class * clss, Method * constructor, uint8 * constructor_args);
+    Class * clss, Method * constructor, U_8 * constructor_args);
 
 #endif /* #ifndef _HEAP_H */

Modified: harmony/enhanced/drlvm/trunk/vm/vmcore/include/mon_enter_exit.h
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/vmcore/include/mon_enter_exit.h?rev=660520&r1=660519&r2=660520&view=diff
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/vmcore/include/mon_enter_exit.h (original)
+++ harmony/enhanced/drlvm/trunk/vm/vmcore/include/mon_enter_exit.h Tue May 27 07:05:55 2008
@@ -28,7 +28,7 @@
 extern "C" {
 #endif
 
-#define P_HASH_CONTENTION_BYTE(x) ( (uint8 *)(x->get_obj_info_addr()) )
+#define P_HASH_CONTENTION_BYTE(x) ( (U_8 *)(x->get_obj_info_addr()) )
 #define P_HASH_CONTENTION(x)      ((POINTER_SIZE_INT)P_HASH_CONTENTION_BYTE(x))
 
 /**

Modified: harmony/enhanced/drlvm/trunk/vm/vmcore/include/vm_arrays.h
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/vmcore/include/vm_arrays.h?rev=660520&r1=660519&r2=660520&view=diff
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/vmcore/include/vm_arrays.h (original)
+++ harmony/enhanced/drlvm/trunk/vm/vmcore/include/vm_arrays.h Tue May 27 07:05:55 2008
@@ -54,16 +54,16 @@
 
 
 
-inline int8 *get_vector_element_address_bool(Vector_Handle vector, I_32 idx)
+inline I_8 *get_vector_element_address_bool(Vector_Handle vector, I_32 idx)
 {
-    return (int8 *)((POINTER_SIZE_INT)vector + (POINTER_SIZE_INT)VM_VECTOR_FIRST_ELEM_OFFSET_1_2_4 + ((POINTER_SIZE_INT)idx * sizeof(int8)));
+    return (I_8 *)((POINTER_SIZE_INT)vector + (POINTER_SIZE_INT)VM_VECTOR_FIRST_ELEM_OFFSET_1_2_4 + ((POINTER_SIZE_INT)idx * sizeof(I_8)));
 } //get_vector_element_address_bool
 
 
 
-inline int8 *get_vector_element_address_int8(Vector_Handle vector, I_32 idx)
+inline I_8 *get_vector_element_address_int8(Vector_Handle vector, I_32 idx)
 {
-    return (int8 *)((POINTER_SIZE_INT)vector + (POINTER_SIZE_INT)VM_VECTOR_FIRST_ELEM_OFFSET_1_2_4 + ((POINTER_SIZE_INT)idx * sizeof(int8)));
+    return (I_8 *)((POINTER_SIZE_INT)vector + (POINTER_SIZE_INT)VM_VECTOR_FIRST_ELEM_OFFSET_1_2_4 + ((POINTER_SIZE_INT)idx * sizeof(I_8)));
 } //get_vector_element_address_int8
 
 

Modified: harmony/enhanced/drlvm/trunk/vm/vmcore/include/vm_strings.h
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/vmcore/include/vm_strings.h?rev=660520&r1=660519&r2=660520&view=diff
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/vmcore/include/vm_strings.h (original)
+++ harmony/enhanced/drlvm/trunk/vm/vmcore/include/vm_strings.h Tue May 27 07:05:55 2008
@@ -36,9 +36,9 @@
  */
 unsigned get_utf8_length_of_unicode(const uint16 *str, unsigned unicode_length);
 int get_unicode_length_of_utf8(const char *utf8);
-unsigned get_utf8_length_of_8bit(const uint8* chars, size_t length);
+unsigned get_utf8_length_of_8bit(const U_8* chars, size_t length);
 void pack_utf8(char *utf8_string, const uint16 *unicode, unsigned unicode_length);
-void utf8_from_8bit(char* utf8_string, const uint8* chars, size_t length);
+void utf8_from_8bit(char* utf8_string, const U_8* chars, size_t length);
 void unpack_utf8(uint16 *unicode, const char *utf8);
 
 Java_java_lang_String *vm_instantiate_cp_string_slow(Class*, unsigned cp_index);

Modified: harmony/enhanced/drlvm/trunk/vm/vmcore/src/class_support/Class_File_Loader.cpp
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/vmcore/src/class_support/Class_File_Loader.cpp?rev=660520&r1=660519&r2=660520&view=diff
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/vmcore/src/class_support/Class_File_Loader.cpp (original)
+++ harmony/enhanced/drlvm/trunk/vm/vmcore/src/class_support/Class_File_Loader.cpp Tue May 27 07:05:55 2008
@@ -290,7 +290,7 @@
 {
     unsigned initial_offset = cfs.get_offset();
 
-    uint8 tag;
+    U_8 tag;
     if (!cfs.parse_u1(&tag)) {
         REPORT_FAILED_CLASS_FORMAT(clss,
             "truncated class file: failed to parse annotation value tag");
@@ -467,7 +467,7 @@
 
 static U_32
 parse_parameter_annotations(AnnotationTable *** table,
-                                        uint8 num_annotations,
+                                        U_8 num_annotations,
                                         ByteReader& cfs, Class* clss)
 {
     unsigned initial_offset = cfs.get_offset();
@@ -1416,7 +1416,7 @@
     //
     // allocate & parse code array
     //
-    _byte_codes = new uint8[_byte_code_length];
+    _byte_codes = new U_8[_byte_code_length];
     // ppervov: FIXME: should throw OOME
 
     unsigned i;
@@ -1587,7 +1587,7 @@
                 return false;
             }
 
-            m_stackmap = (uint8*)Method::Alloc(attr_len + 6);
+            m_stackmap = (U_8*)Method::Alloc(attr_len + 6);
             if(!cfs.skip(-6)) { // read once again attribute head
                 REPORT_FAILED_CLASS_CLASS(_class->get_class_loader(), _class, "java/lang/InternalError",
                     _class->get_name()->bytes << ": inernal error: unable to read beginning of an attribute");
@@ -2320,13 +2320,13 @@
     if(!cfs.have(len))
         return NULL;
     //define bytes of UTF8
-    const uint8 HIGH_NONZERO_BIT =          0x80; // 10000000
-    const uint8 HIGH_TWO_NONZERO_BITS =     0xc0; // 11000000
-    const uint8 HIGH_THREE_NONZERO_BITS =   0xe0; // 11100000
-    const uint8 HIGH_FOUR_NONZERO_BITS =    0xf0; // 11110000
+    const U_8 HIGH_NONZERO_BIT =          0x80; // 10000000
+    const U_8 HIGH_TWO_NONZERO_BITS =     0xc0; // 11000000
+    const U_8 HIGH_THREE_NONZERO_BITS =   0xe0; // 11100000
+    const U_8 HIGH_FOUR_NONZERO_BITS =    0xf0; // 11110000
     
     // get utf8 bytes and move buffer pointer
-    uint8* utf8data = (uint8*)cfs.get_and_skip(len);
+    U_8* utf8data = (U_8*)cfs.get_and_skip(len);
 
     // FIXME: decode 6-byte Java 1.5 encoding
     
@@ -2397,7 +2397,7 @@
     cp_tags[0] = CONSTANT_Tags;
     for(unsigned i = 1; i < m_size; i++) {
         // parse tag into tag array
-        uint8 tag;
+        U_8 tag;
         if(!cfs.parse_u1(&tag)) {
             REPORT_FAILED_CLASS_FORMAT(clss, "truncated class file: failed to parse constant pool tag for index " << i);
             return false;
@@ -3329,7 +3329,7 @@
 
 static bool const_pool_find_entry(ByteReader& cp, uint16 cp_count, uint16 index)
 {
-    uint8 tag;
+    U_8 tag;
     // cp must be at the beginning of constant pool
     for(uint16 cp_index = 1; cp_index < cp_count; cp_index++) {
         if(cp_index == index) return true;
@@ -3382,7 +3382,7 @@
 
 
 const String* class_extract_name(Global_Env* env,
-                                 uint8* buffer, unsigned offset, unsigned length)
+                                 U_8* buffer, unsigned offset, unsigned length)
 {
     ByteReader cfs(buffer, offset, length);
 
@@ -3401,7 +3401,7 @@
         return NULL;
 
     // skip constant pool
-    uint8 tag;
+    U_8 tag;
     uint16 utf8_len;
     offset = cfs.get_offset(); // offset now contains the start of constant pool
     uint16 cp_index;

Modified: harmony/enhanced/drlvm/trunk/vm/vmcore/src/class_support/classloader.cpp
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/vmcore/src/class_support/classloader.cpp?rev=660520&r1=660519&r2=660520&view=diff
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/vmcore/src/class_support/classloader.cpp (original)
+++ harmony/enhanced/drlvm/trunk/vm/vmcore/src/class_support/classloader.cpp Tue May 27 07:05:55 2008
@@ -67,7 +67,7 @@
 
 // external declaration; definition is in Class_File_Loader.cpp
 const String* class_extract_name(Global_Env* env,
-                                 uint8* buffer,
+                                 U_8* buffer,
                                  unsigned offset, unsigned length);
 
 
@@ -251,7 +251,7 @@
 }
 
 Class* ClassLoader::DefineClass(Global_Env* env, const char* class_name,
-                                uint8* bytecode, unsigned offset, unsigned length,
+                                U_8* bytecode, unsigned offset, unsigned length,
                                 const String** res_name)
 {
     assert(!exn_raised());
@@ -288,7 +288,7 @@
     if((clss = WaitDefinition(env, className)) != NULL || exn_raised())
         return clss;
 
-    uint8 *redef_buf = NULL;
+    U_8 *redef_buf = NULL;
     int redef_buflen = 0;
     if(jvmti_should_report_event(JVMTI_EVENT_CLASS_FILE_LOAD_HOOK)) {
         jvmti_send_class_file_load_hook_event(env, this, class_name,

Modified: harmony/enhanced/drlvm/trunk/vm/vmcore/src/exception/exceptions_jit.cpp
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/vmcore/src/exception/exceptions_jit.cpp?rev=660520&r1=660519&r2=660520&view=diff
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/vmcore/src/exception/exceptions_jit.cpp (original)
+++ harmony/enhanced/drlvm/trunk/vm/vmcore/src/exception/exceptions_jit.cpp Tue May 27 07:05:55 2008
@@ -144,7 +144,7 @@
 static ManagedObject *create_lazy_exception(
     Class_Handle exn_class,
     Method_Handle exn_constr,
-    uint8 * exn_constr_args,
+    U_8 * exn_constr_args,
     jvalue* vm_exn_constr_args)
 {
     assert(!hythread_is_suspend_enabled());
@@ -194,7 +194,7 @@
     ManagedObject ** exn_obj,
     Class_Handle exn_class,
     Method_Handle exn_constr,
-    uint8 * jit_exn_constr_args,
+    U_8 * jit_exn_constr_args,
     jvalue* vm_exn_constr_args)
 {
     assert(!hythread_is_suspend_enabled());
@@ -448,7 +448,7 @@
 
 // function can be safe point & should be called with disable reqursion = 1
 void exn_throw_for_JIT(ManagedObject* exn_obj, Class_Handle exn_class,
-    Method_Handle exn_constr, uint8* jit_exn_constr_args, jvalue* vm_exn_constr_args)
+    Method_Handle exn_constr, U_8* jit_exn_constr_args, jvalue* vm_exn_constr_args)
 {
 /*
  * !!!! NO LOGGER IS ALLOWED IN THIS FUNCTION !!!
@@ -539,7 +539,7 @@
 
 // function can be safe point & should be called with disable reqursion = 1
 void exn_athrow(ManagedObject* exn_obj, Class_Handle exn_class,
-    Method_Handle exn_constr, uint8* exn_constr_args)
+    Method_Handle exn_constr, U_8* exn_constr_args)
 {
     assert(!hythread_is_suspend_enabled());
     BEGIN_RAISE_AREA;
@@ -789,7 +789,7 @@
 #if defined(_IPF_) || defined(_EM64T_)
     DIE(("Lazy exceptions are not supported on this platform"));
 #else
-    uint8 *args = (uint8 *) (m2n_get_args(m2n_get_last_frame()) + 1);   // +1 to skip constructor
+    U_8 *args = (U_8 *) (m2n_get_args(m2n_get_last_frame()) + 1);   // +1 to skip constructor
     if (NULL != exn_constr) {
         args += exn_constr->get_num_arg_slots() * 4 - 4;
     } else {

Modified: harmony/enhanced/drlvm/trunk/vm/vmcore/src/jit/jit_runtime_support.cpp
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/vmcore/src/jit/jit_runtime_support.cpp?rev=660520&r1=660519&r2=660520&view=diff
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/vmcore/src/jit/jit_runtime_support.cpp (original)
+++ harmony/enhanced/drlvm/trunk/vm/vmcore/src/jit/jit_runtime_support.cpp Tue May 27 07:05:55 2008
@@ -1807,7 +1807,7 @@
 ManagedObject*
 class_alloc_new_object_and_run_constructor(Class* clss,
                                            Method* constructor,
-                                           uint8* constructor_args)
+                                           U_8* constructor_args)
 {
     ASSERT_RAISE_AREA;
     assert(!hythread_is_suspend_enabled());
@@ -1832,7 +1832,7 @@
     args[0].l = (jobject)obj;
 
     int arg_num = 1;
-    uint8* argp = constructor_args;
+    U_8* argp = constructor_args;
     Arg_List_Iterator iter = constructor->get_argument_list();
     Java_Type typ;
     while((typ = curr_arg(iter)) != JAVA_TYPE_END) {

Modified: harmony/enhanced/drlvm/trunk/vm/vmcore/src/jni/jni.cpp
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/vmcore/src/jni/jni.cpp?rev=660520&r1=660519&r2=660520&view=diff
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/vmcore/src/jni/jni.cpp (original)
+++ harmony/enhanced/drlvm/trunk/vm/vmcore/src/jni/jni.cpp Tue May 27 07:05:55 2008
@@ -656,7 +656,7 @@
     }
 
     const String* res_name;
-    Class* clss = cl->DefineClass(env, name, (uint8 *)buf, 0, len, &res_name);
+    Class* clss = cl->DefineClass(env, name, (U_8 *)buf, 0, len, &res_name);
 
     bool ld_result;
     if(clss != NULL)

Modified: harmony/enhanced/drlvm/trunk/vm/vmcore/src/jvmti/jvmti_class.cpp
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/vmcore/src/jvmti/jvmti_class.cpp?rev=660520&r1=660519&r2=660520&view=diff
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/vmcore/src/jvmti/jvmti_class.cpp (original)
+++ harmony/enhanced/drlvm/trunk/vm/vmcore/src/jvmti/jvmti_class.cpp Tue May 27 07:05:55 2008
@@ -365,13 +365,13 @@
         GetClassSignature( klass, signature );
         TRACE2("jvmti-class", "Class signature = " << signature);
         // allocate memory for class UTF8 signature
-        len = get_utf8_length_of_8bit( (const uint8*)signature, sig_len);
+        len = get_utf8_length_of_8bit( (const U_8*)signature, sig_len);
         result = _allocate( len + 1, (unsigned char**)&pointer );
         if( result != JVMTI_ERROR_NONE ) {
             return result;
         }
         // copy class UTF8 signature
-        utf8_from_8bit( pointer, (const uint8*)signature, sig_len );
+        utf8_from_8bit( pointer, (const U_8*)signature, sig_len );
         // set class UTF8 signature
         *sig = pointer;
         // free memory for class signature

Modified: harmony/enhanced/drlvm/trunk/vm/vmcore/src/jvmti/jvmti_event.cpp
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/vmcore/src/jvmti/jvmti_event.cpp?rev=660520&r1=660519&r2=660520&view=diff
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/vmcore/src/jvmti/jvmti_event.cpp (original)
+++ harmony/enhanced/drlvm/trunk/vm/vmcore/src/jvmti/jvmti_event.cpp Tue May 27 07:05:55 2008
@@ -658,7 +658,7 @@
 
                     for (int i = 0; i < code_size; i++)
                     {
-                        NativeCodePtr ip = (NativeCodePtr) (((uint8*) code_addr) + i);
+                        NativeCodePtr ip = (NativeCodePtr) (((U_8*) code_addr) + i);
                         uint16 bc = 12345;
 
                         OpenExeJpdaError UNREF result =

Modified: harmony/enhanced/drlvm/trunk/vm/vmcore/src/jvmti/jvmti_method.cpp
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/vmcore/src/jvmti/jvmti_method.cpp?rev=660520&r1=660519&r2=660520&view=diff
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/vmcore/src/jvmti/jvmti_method.cpp (original)
+++ harmony/enhanced/drlvm/trunk/vm/vmcore/src/jvmti/jvmti_method.cpp Tue May 27 07:05:55 2008
@@ -442,36 +442,36 @@
             &(entry->slot),
             &name, &type, &generic_type);
         // allocate memory for name
-        len = get_utf8_length_of_8bit( (const uint8*)name->bytes, name->len);
+        len = get_utf8_length_of_8bit( (const U_8*)name->bytes, name->len);
         result = _allocate( len + 1, (unsigned char**)&pointer );
         if( result != JVMTI_ERROR_NONE ) {
             return result;
         }
         // copy variable name
-        utf8_from_8bit( pointer, (const uint8*)name->bytes, name->len);
+        utf8_from_8bit( pointer, (const U_8*)name->bytes, name->len);
         // set variable name
         entry->name = pointer;
         // allocate memory for signature
-        len = get_utf8_length_of_8bit( (const uint8*)type->bytes, type->len);
+        len = get_utf8_length_of_8bit( (const U_8*)type->bytes, type->len);
         result = _allocate( len + 1, (unsigned char**)&pointer );
         if( result != JVMTI_ERROR_NONE ) {
             return result;
         }
         // copy variable signature
-        utf8_from_8bit( pointer, (const uint8*)type->bytes, type->len);
+        utf8_from_8bit( pointer, (const U_8*)type->bytes, type->len);
         // set variable signature
         entry->signature = pointer;
         // set variable slot
 
         if (generic_type) {
             // allocate memory for generic_signature
-            len = get_utf8_length_of_8bit( (const uint8*)generic_type->bytes, generic_type->len);
+            len = get_utf8_length_of_8bit( (const U_8*)generic_type->bytes, generic_type->len);
             result = _allocate( len + 1, (unsigned char**)&pointer );
             if( result != JVMTI_ERROR_NONE ) {
                 return result;
             }
             // copy variable generic_signature
-            utf8_from_8bit( pointer, (const uint8*)generic_type->bytes, generic_type->len);
+            utf8_from_8bit( pointer, (const U_8*)generic_type->bytes, generic_type->len);
             // set variable generic_signature
             entry->generic_signature = pointer;
         } else {

Modified: harmony/enhanced/drlvm/trunk/vm/vmcore/src/lil/em64t/lil_code_generator_em64t.cpp
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/vmcore/src/lil/em64t/lil_code_generator_em64t.cpp?rev=660520&r1=660519&r2=660520&view=diff
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/vmcore/src/lil/em64t/lil_code_generator_em64t.cpp (original)
+++ harmony/enhanced/drlvm/trunk/vm/vmcore/src/lil/em64t/lil_code_generator_em64t.cpp Tue May 27 07:05:55 2008
@@ -1237,7 +1237,7 @@
                     result = ~imm;
                     break;
                 case LO_Sx1:
-                    result = (I_32) (int8) imm;
+                    result = (I_32) (I_8) imm;
                     break;
                 case LO_Sx2:
                     result = (I_32) (int16) imm;
@@ -1246,7 +1246,7 @@
                     result = (I_32) (I_32) imm;
                     break;
                 case LO_Zx1:
-                    result = (I_32) (uint64) (uint8) imm;
+                    result = (I_32) (uint64) (U_8) imm;
                     break;
                 case LO_Zx2:
                     result = (I_32) (uint64) (uint16) imm;

Modified: harmony/enhanced/drlvm/trunk/vm/vmcore/src/lil/ipf/lil_code_generator_ipf.cpp
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/vmcore/src/lil/ipf/lil_code_generator_ipf.cpp?rev=660520&r1=660519&r2=660520&view=diff
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/vmcore/src/lil/ipf/lil_code_generator_ipf.cpp (original)
+++ harmony/enhanced/drlvm/trunk/vm/vmcore/src/lil/ipf/lil_code_generator_ipf.cpp Tue May 27 07:05:55 2008
@@ -1586,7 +1586,7 @@
                     result = ~imm;
                     break;
                 case LO_Sx1:
-                    result = (int64) (int8) imm;
+                    result = (int64) (I_8) imm;
                     break;
                 case LO_Sx2:
                     result = (int64) (int16) imm;
@@ -1595,7 +1595,7 @@
                     result = (int64) (I_32) imm;
                     break;
                 case LO_Zx1:
-                    result = (int64) (uint64) (uint8) imm;
+                    result = (int64) (uint64) (U_8) imm;
                     break;
                 case LO_Zx2:
                     result = (int64) (uint64) (uint16) imm;

Modified: harmony/enhanced/drlvm/trunk/vm/vmcore/src/lil/lil_code_generator_utils.cpp
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/vmcore/src/lil/lil_code_generator_utils.cpp?rev=660520&r1=660519&r2=660520&view=diff
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/vmcore/src/lil/lil_code_generator_utils.cpp (original)
+++ harmony/enhanced/drlvm/trunk/vm/vmcore/src/lil/lil_code_generator_utils.cpp Tue May 27 07:05:55 2008
@@ -110,8 +110,8 @@
     switch (patch->type) {
     case LPT_Rel8:
         diff = (int64)((char *)label_adress->addr - ((char *)patch->addr + 1));
-        assert(diff == (int64)(int8)diff);
-        *(int8*)patch->addr = (int8)diff;
+        assert(diff == (int64)(I_8)diff);
+        *(I_8*)patch->addr = (I_8)diff;
         break;
     case LPT_Rel32:
         diff = (int64)((char *)label_adress->addr - (char *)((I_32 *)patch->addr + 1));

Modified: harmony/enhanced/drlvm/trunk/vm/vmcore/src/ncai/utils/ncai_utils_em64t.cpp
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/vmcore/src/ncai/utils/ncai_utils_em64t.cpp?rev=660520&r1=660519&r2=660520&view=diff
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/vmcore/src/ncai/utils/ncai_utils_em64t.cpp (original)
+++ harmony/enhanced/drlvm/trunk/vm/vmcore/src/ncai/utils/ncai_utils_em64t.cpp Tue May 27 07:05:55 2008
@@ -191,7 +191,7 @@
 
     memcpy(
         buf_ptr,
-        ((uint8*)&regs) + g_ncai_reg_table[reg_number].offset,
+        ((U_8*)&regs) + g_ncai_reg_table[reg_number].offset,
         g_ncai_reg_table[reg_number].size);
 
     return true;
@@ -209,7 +209,7 @@
     ncai_context_to_registers(&context, &regs);
 
     memcpy(
-        ((uint8*)&regs) + g_ncai_reg_table[reg_number].offset,
+        ((U_8*)&regs) + g_ncai_reg_table[reg_number].offset,
         buf_ptr,
         g_ncai_reg_table[reg_number].size);
 

Modified: harmony/enhanced/drlvm/trunk/vm/vmcore/src/ncai/utils/ncai_utils_ia32.cpp
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/vmcore/src/ncai/utils/ncai_utils_ia32.cpp?rev=660520&r1=660519&r2=660520&view=diff
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/vmcore/src/ncai/utils/ncai_utils_ia32.cpp (original)
+++ harmony/enhanced/drlvm/trunk/vm/vmcore/src/ncai/utils/ncai_utils_ia32.cpp Tue May 27 07:05:55 2008
@@ -163,7 +163,7 @@
 
     memcpy(
         buf_ptr,
-        ((uint8*)&regs) + g_ncai_reg_table[reg_number].offset,
+        ((U_8*)&regs) + g_ncai_reg_table[reg_number].offset,
         g_ncai_reg_table[reg_number].size);
 
     return true;
@@ -181,7 +181,7 @@
     ncai_context_to_registers(&context, &regs);
 
     memcpy(
-        ((uint8*)&regs) + g_ncai_reg_table[reg_number].offset,
+        ((U_8*)&regs) + g_ncai_reg_table[reg_number].offset,
         buf_ptr,
         g_ncai_reg_table[reg_number].size);
 

Modified: harmony/enhanced/drlvm/trunk/vm/vmcore/src/ncai/utils/ncai_utils_ipf.cpp
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/vmcore/src/ncai/utils/ncai_utils_ipf.cpp?rev=660520&r1=660519&r2=660520&view=diff
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/vmcore/src/ncai/utils/ncai_utils_ipf.cpp (original)
+++ harmony/enhanced/drlvm/trunk/vm/vmcore/src/ncai/utils/ncai_utils_ipf.cpp Tue May 27 07:05:55 2008
@@ -214,7 +214,7 @@
 
     memcpy(
         buf_ptr,
-        ((uint8*)&regs) + g_ncai_reg_table[reg_number].offset,
+        ((U_8*)&regs) + g_ncai_reg_table[reg_number].offset,
         g_ncai_reg_table[reg_number].size);
 
     return true;
@@ -232,7 +232,7 @@
     ncai_context_to_registers(&context, &regs);
 
     memcpy(
-        ((uint8*)&regs) + g_ncai_reg_table[reg_number].offset,
+        ((U_8*)&regs) + g_ncai_reg_table[reg_number].offset,
         buf_ptr,
         g_ncai_reg_table[reg_number].size);
 

Modified: harmony/enhanced/drlvm/trunk/vm/vmcore/src/object/vm_arrays.cpp
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/vmcore/src/object/vm_arrays.cpp?rev=660520&r1=660519&r2=660520&view=diff
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/vmcore/src/object/vm_arrays.cpp (original)
+++ harmony/enhanced/drlvm/trunk/vm/vmcore/src/object/vm_arrays.cpp Tue May 27 07:05:55 2008
@@ -488,7 +488,7 @@
 #endif
         memmove(get_vector_element_address_int8(dst, dstOffset),
                 get_vector_element_address_int8(src, srcOffset),
-                length * sizeof(int8));
+                length * sizeof(I_8));
         break;
     case 'Z':
 #ifdef VM_STATS
@@ -496,7 +496,7 @@
 #endif
         memmove(get_vector_element_address_bool(dst, dstOffset),
                 get_vector_element_address_bool(src, srcOffset),
-                length * sizeof(int8));
+                length * sizeof(I_8));
         break;
     case 'S':
 #ifdef VM_STATS

Modified: harmony/enhanced/drlvm/trunk/vm/vmcore/src/stack/stack_trace.cpp
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/vmcore/src/stack/stack_trace.cpp?rev=660520&r1=660519&r2=660520&view=diff
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/vmcore/src/stack/stack_trace.cpp (original)
+++ harmony/enhanced/drlvm/trunk/vm/vmcore/src/stack/stack_trace.cpp Tue May 27 07:05:55 2008
@@ -47,7 +47,7 @@
 
     *line = -1;
     if (interpreter_enabled()) {
-        int bc = (int)((uint8*)ip - (uint8*)method->get_byte_code_addr());
+        int bc = (int)((U_8*)ip - (U_8*)method->get_byte_code_addr());
         *line = method->get_line_number((uint16)bc);
         return;
     }

Modified: harmony/enhanced/drlvm/trunk/vm/vmcore/src/thread/atomics_common.cpp
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/vmcore/src/thread/atomics_common.cpp?rev=660520&r1=660519&r2=660520&view=diff
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/vmcore/src/thread/atomics_common.cpp (original)
+++ harmony/enhanced/drlvm/trunk/vm/vmcore/src/thread/atomics_common.cpp Tue May 27 07:05:55 2008
@@ -126,7 +126,7 @@
     U_8* java_ref = (U_8*)h->object;
     jboolean* field_addr = (jboolean*)(java_ref + offset);
     bool result =
-        (port_atomic_cas8((uint8*)field_addr, (uint8)value, (uint8)expected) == (uint8)expected);
+        (port_atomic_cas8((U_8*)field_addr, (U_8)value, (U_8)expected) == (U_8)expected);
 
     tmn_suspend_enable();
     return (jboolean)(result?JNI_TRUE:JNI_FALSE);
@@ -221,7 +221,7 @@
             index);
 
     bool result =
-        (port_atomic_cas8((uint8 *)field_addr, (uint8)value, (uint8)expected) == (uint8)expected);
+        (port_atomic_cas8((U_8 *)field_addr, (U_8)value, (U_8)expected) == (U_8)expected);
 
     tmn_suspend_enable();
     return (jboolean)(result?JNI_TRUE:JNI_FALSE);

Modified: harmony/enhanced/drlvm/trunk/vm/vmcore/src/thread/object_generic.cpp
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/vmcore/src/thread/object_generic.cpp?rev=660520&r1=660519&r2=660520&view=diff
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/vmcore/src/thread/object_generic.cpp (original)
+++ harmony/enhanced/drlvm/trunk/vm/vmcore/src/thread/object_generic.cpp Tue May 27 07:05:55 2008
@@ -43,7 +43,7 @@
 
 void set_hash_bits(ManagedObject *p_obj)
     {
-    uint8 hb = (uint8) (((POINTER_SIZE_INT)p_obj >> 3) & HASH_MASK)  ;
+    U_8 hb = (U_8) (((POINTER_SIZE_INT)p_obj >> 3) & HASH_MASK)  ;
     // lowest 3 bits are not random enough so get rid of them
 
     if (hb == 0)

Modified: harmony/enhanced/drlvm/trunk/vm/vmcore/src/util/bytereader.cpp
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/vmcore/src/util/bytereader.cpp?rev=660520&r1=660519&r2=660520&view=diff
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/vmcore/src/util/bytereader.cpp (original)
+++ harmony/enhanced/drlvm/trunk/vm/vmcore/src/util/bytereader.cpp Tue May 27 07:05:55 2008
@@ -31,7 +31,7 @@
     int num_columns = 8;
     bool first_time = true;
     int curr_offset = get_offset();
-    const uint8* curr_byte = curr;
+    const U_8* curr_byte = curr;
     for(unsigned i = 0; i < num_bytes; i++, curr_offset++, curr_byte++) {
         if(first_time || !(curr_offset & (num_columns - 1))) {
             if(!first_time) {
@@ -46,7 +46,7 @@
                 }
             }
         }
-        uint8 b = *curr_byte;
+        U_8 b = *curr_byte;
         printf("%02x", b);
         if(b >= 32 && b < 127) {
             printf(" '%c'  ", b);

Modified: harmony/enhanced/drlvm/trunk/vm/vmcore/src/util/crash_dump.cpp
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/vmcore/src/util/crash_dump.cpp?rev=660520&r1=660519&r2=660520&view=diff
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/vmcore/src/util/crash_dump.cpp (original)
+++ harmony/enhanced/drlvm/trunk/vm/vmcore/src/util/crash_dump.cpp Tue May 27 07:05:55 2008
@@ -170,7 +170,7 @@
         if (is_java)
         {
             Method* method = (Method*)interpreter.interpreter_get_frame_method(uwinfo->frame);
-            uint8* bc_ptr = interpreter.interpreter_get_frame_bytecode_ptr(uwinfo->frame);
+            U_8* bc_ptr = interpreter.interpreter_get_frame_bytecode_ptr(uwinfo->frame);
             cd_fill_java_method_info(method, (void*)bc_ptr, false, -1, sfi);
             uwinfo->frame = interpreter.interpreter_get_prev_frame(uwinfo->frame);
         }

Modified: harmony/enhanced/drlvm/trunk/vm/vmcore/src/util/ipf/base/ini_ipf.cpp
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/vmcore/src/util/ipf/base/ini_ipf.cpp?rev=660520&r1=660519&r2=660520&view=diff
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/vmcore/src/util/ipf/base/ini_ipf.cpp (original)
+++ harmony/enhanced/drlvm/trunk/vm/vmcore/src/util/ipf/base/ini_ipf.cpp Tue May 27 07:05:55 2008
@@ -279,10 +279,10 @@
         *((uint16 *)return_value) = (uint16) int_result;
         break;
     case JAVA_TYPE_BYTE:
-        *((int8 *)return_value) = (int8) int_result;
+        *((I_8 *)return_value) = (I_8) int_result;
         break;
     case JAVA_TYPE_BOOLEAN:
-        *((uint8 *)return_value) = (uint8) int_result;
+        *((U_8 *)return_value) = (U_8) int_result;
         break;
     case JAVA_TYPE_DOUBLE:
         *((double *)return_value) = double_result;

Modified: harmony/enhanced/drlvm/trunk/vm/vmcore/src/util/ipf/include/merced.h
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/vmcore/src/util/ipf/include/merced.h?rev=660520&r1=660519&r2=660520&view=diff
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/vmcore/src/util/ipf/include/merced.h (original)
+++ harmony/enhanced/drlvm/trunk/vm/vmcore/src/util/ipf/include/merced.h Tue May 27 07:05:55 2008
@@ -724,9 +724,9 @@
 struct Template_Descr {
    EM_Syllable_Type syl_type[ENC_N_SLOTS];
    // Slot number after stop, or ENC_N_SLOTS if no stop
-   uint8 stop_up;
+   U_8 stop_up;
    // Slot number after stop, or 0 if no stop
-   uint8 stop_down;
+   U_8 stop_down;
 };
 
 extern Template_Descr tmplt_descr[];

Modified: harmony/enhanced/drlvm/trunk/vm/vmcore/src/util/vm_strings.cpp
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/vmcore/src/util/vm_strings.cpp?rev=660520&r1=660519&r2=660520&view=diff
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/vmcore/src/util/vm_strings.cpp (original)
+++ harmony/enhanced/drlvm/trunk/vm/vmcore/src/util/vm_strings.cpp Tue May 27 07:05:55 2008
@@ -38,9 +38,9 @@
 int get_unicode_length_of_utf8(const char *utf8)
 {
     int len = 0;
-    uint8 ch;
-    uint8 ch2;
-    uint8 ch3;
+    U_8 ch;
+    U_8 ch2;
+    U_8 ch3;
     while((ch = *utf8++)) {
         len++;
         if(ch & 0x80) { // 2 or 3 byte encoding
@@ -80,7 +80,7 @@
     return length;
 } //get_utf8_length_of_unicode
 
-unsigned get_utf8_length_of_8bit(const uint8* chars, size_t length)
+unsigned get_utf8_length_of_8bit(const U_8* chars, size_t length)
 {
     unsigned len = 0;
     for(unsigned i=0; i < length; i++)
@@ -118,7 +118,7 @@
     *s = 0;
 } //pack_utf8
 
-void utf8_from_8bit(char* utf8_string, const uint8* chars, size_t length)
+void utf8_from_8bit(char* utf8_string, const U_8* chars, size_t length)
 {
     char* s = utf8_string;
     for(unsigned i=0; i<length; i++) {
@@ -140,7 +140,7 @@
 
 void unpack_utf8(uint16 *unicode, const char *utf8_string)
 {
-    const uint8 *utf8 = (const uint8 *)utf8_string;
+    const U_8 *utf8 = (const U_8 *)utf8_string;
     unsigned len = 0;
     uint16 ch;
     while((ch = (uint16)*utf8++)) {
@@ -175,7 +175,7 @@
 // otherwise the characters are stored as 16-bit and unicode points to the array.
 struct StringBuffer {
     uint16* unicode;
-    uint8* compressed;
+    U_8* compressed;
     bool is_compressed;
 };
 
@@ -277,7 +277,7 @@
     *str = jls;
     buf->is_compressed = eight_bit;
     if (eight_bit)
-        buf->compressed = (uint8*)get_vector_element_address_int8(array, 0);
+        buf->compressed = (U_8*)get_vector_element_address_int8(array, 0);
     else
         buf->unicode = get_vector_element_address_uint16(array, 0);
 }
@@ -328,7 +328,7 @@
     }
     if (buf2.is_compressed) {
         for(unsigned i=0; i<length; i++)
-            buf2.compressed[i] = (uint8)buf[i];
+            buf2.compressed[i] = (U_8)buf[i];
     } else {
         memcpy(buf2.unicode, buf, sizeof(uint16) * length);
     }
@@ -424,7 +424,7 @@
     } else {
         buf->is_compressed = true;
         assert(f_value_byte_offset);
-        buf->compressed = (uint8*)get_vector_element_address_int8(*(Vector_Handle*)(str_raw+f_value_byte_offset), offset);
+        buf->compressed = (U_8*)get_vector_element_address_int8(*(Vector_Handle*)(str_raw+f_value_byte_offset), offset);
     }
 }
 

Modified: harmony/enhanced/drlvm/trunk/vm/vmcore/src/verifier-3363/base/context_base.h
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/vmcore/src/verifier-3363/base/context_base.h?rev=660520&r1=660519&r2=660520&view=diff
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/vmcore/src/verifier-3363/base/context_base.h (original)
+++ harmony/enhanced/drlvm/trunk/vm/vmcore/src/verifier-3363/base/context_base.h Tue May 27 07:05:55 2008
@@ -145,7 +145,7 @@
     /******* exception handling **********/
 
     //flag array. if a local var i was changed by the previous instruction ==> changed_locals[i]=1, otherwise it's 0
-    uint8 *changed_locals;
+    U_8 *changed_locals;
 
     //if there is at least one local changed
     int locals_changed;
@@ -191,7 +191,7 @@
         // initialize own parameters
         mem.init();
 
-        changed_locals = (uint8*)mem.malloc((m_stack_start & ~3) + 4);
+        changed_locals = (U_8*)mem.malloc((m_stack_start & ~3) + 4);
 
         //to correct it later
         return_type = SM_NONE;
@@ -229,7 +229,7 @@
     }
 
     //get the length of the given instruction or minimal length if unknown
-    static uint8 instr_get_minlen(ParseInfo &pi) {
+    static U_8 instr_get_minlen(ParseInfo &pi) {
         return pi.instr_min_len;
     }
 
@@ -264,7 +264,7 @@
     }
 
     //RET ?
-    static int instr_is_ret(OpCode opcode, uint8* code, Address instr) {
+    static int instr_is_ret(OpCode opcode, U_8* code, Address instr) {
         return opcode == OP_RET || opcode == OP_WIDE && code[instr + 1] == OP_RET;
     }
 

Modified: harmony/enhanced/drlvm/trunk/vm/vmcore/src/verifier-3363/base/context_x.cpp
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/vmcore/src/verifier-3363/base/context_x.cpp?rev=660520&r1=660519&r2=660520&view=diff
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/vmcore/src/verifier-3363/base/context_x.cpp (original)
+++ harmony/enhanced/drlvm/trunk/vm/vmcore/src/verifier-3363/base/context_x.cpp Tue May 27 07:05:55 2008
@@ -426,7 +426,7 @@
         case OP_ALOAD_0: case OP_ALOAD_1: 
         case OP_ALOAD_2: case OP_ALOAD_3: {
             //get local index from opcode
-            uint8 local_idx =  opcode - OP_ALOAD_0;
+            U_8 local_idx =  opcode - OP_ALOAD_0;
 
             //call macro
             CHECK_ALOAD( local_idx );
@@ -489,7 +489,7 @@
         case OP_ASTORE_0: case OP_ASTORE_1: 
         case OP_ASTORE_2: case OP_ASTORE_3: {
             //get local index from opcode
-            uint8 local_idx =  opcode - OP_ASTORE_0;
+            U_8 local_idx =  opcode - OP_ASTORE_0;
 
             //call MACRO
             CHECK_ASTORE( local_idx );
@@ -667,7 +667,7 @@
         case OP_DLOAD_0: case OP_DLOAD_1: 
         case OP_DLOAD_2: case OP_DLOAD_3: {
             //get local index from opcode
-            uint8 local_idx =  opcode - OP_DLOAD_0;
+            U_8 local_idx =  opcode - OP_DLOAD_0;
 
             //call macro
             CHECK_xxLOAD( local_idx, SM_DOUBLE );
@@ -701,7 +701,7 @@
         case OP_DSTORE_0: case OP_DSTORE_1: 
         case OP_DSTORE_2: case OP_DSTORE_3: {
             //get local index from opcode
-            uint8 local_idx =  opcode - OP_DSTORE_0;
+            U_8 local_idx =  opcode - OP_DSTORE_0;
 
             CHECK_xxSTORE( local_idx, SM_DOUBLE );
 
@@ -945,7 +945,7 @@
         case OP_FLOAD_0: case OP_FLOAD_1: 
         case OP_FLOAD_2: case OP_FLOAD_3: {
             //get local index from opcode
-            uint8 local_idx =  opcode - OP_FLOAD_0;
+            U_8 local_idx =  opcode - OP_FLOAD_0;
 
             //call macro
             CHECK_xLOAD( local_idx, SM_FLOAT );
@@ -979,7 +979,7 @@
         case OP_FSTORE_0: case OP_FSTORE_1: 
         case OP_FSTORE_2: case OP_FSTORE_3: {
             //get local index from opcode
-            uint8 local_idx =  opcode - OP_FSTORE_0;
+            U_8 local_idx =  opcode - OP_FSTORE_0;
 
             CHECK_xSTORE( local_idx, SM_FLOAT );
 
@@ -1135,7 +1135,7 @@
         case OP_ILOAD_0: case OP_ILOAD_1: 
         case OP_ILOAD_2: case OP_ILOAD_3: {
             //get local index from opcode
-            uint8 local_idx =  opcode - OP_ILOAD_0;
+            U_8 local_idx =  opcode - OP_ILOAD_0;
 
             //call macro
             CHECK_xLOAD( local_idx, SM_INTEGER );
@@ -1181,7 +1181,7 @@
         case OP_ISTORE_0: case OP_ISTORE_1: 
         case OP_ISTORE_2: case OP_ISTORE_3: {
             //get local index from opcode
-            uint8 local_idx =  opcode - OP_ISTORE_0;
+            U_8 local_idx =  opcode - OP_ISTORE_0;
 
             CHECK_xSTORE( local_idx, SM_INTEGER );
 
@@ -1316,7 +1316,7 @@
         case OP_LLOAD_0: case OP_LLOAD_1: 
         case OP_LLOAD_2: case OP_LLOAD_3: {
             //get local index from opcode
-            uint8 local_idx =  opcode - OP_LLOAD_0;
+            U_8 local_idx =  opcode - OP_LLOAD_0;
 
             //call macro
             CHECK_xxLOAD( local_idx, SM_LONG );
@@ -1350,7 +1350,7 @@
         case OP_LSTORE_0: case OP_LSTORE_1: 
         case OP_LSTORE_2: case OP_LSTORE_3: {
             //get local index from opcode
-            uint8 local_idx =  opcode - OP_LSTORE_0;
+            U_8 local_idx =  opcode - OP_LSTORE_0;
 
             CHECK_xxSTORE( local_idx, SM_LONG );
 
@@ -1423,7 +1423,7 @@
         case OP_NEWARRAY: {
             POP_x( SM_INTEGER );
 
-            uint8 array_type = m_bytecode[instr + 1];
+            U_8 array_type = m_bytecode[instr + 1];
             if( array_type < 4 || array_type > 11 ) return error(VF_ErrorInstruction, "bad array type");
 
             SmConstant ref = tpool.sm_get_const_arrayref(array_type);
@@ -1617,8 +1617,8 @@
             if( opcode == OP_INVOKEINTERFACE ) {
                 //TODO: is verifier the right place for this check?
                 //check 'count' value for invokeinterface instruction
-                uint8 count = m_bytecode[instr + 3];
-                uint8 fourth = m_bytecode[instr + 4];
+                U_8 count = m_bytecode[instr + 3];
+                U_8 fourth = m_bytecode[instr + 4];
                 if( count != args_sz + 1 || fourth ) {
                     return error(VF_ErrorUnknown, "incorrect invokeinterface instruction");
                 }

Modified: harmony/enhanced/drlvm/trunk/vm/vmcore/src/verifier-3363/base/instr_props.h
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/vmcore/src/verifier-3363/base/instr_props.h?rev=660520&r1=660519&r2=660520&view=diff
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/vmcore/src/verifier-3363/base/instr_props.h (original)
+++ harmony/enhanced/drlvm/trunk/vm/vmcore/src/verifier-3363/base/instr_props.h Tue May 27 07:05:55 2008
@@ -23,15 +23,15 @@
 //
 // instruction's possible characteristics (flags)
 //
-const uint8 PI_JUMP = 1;
-const uint8 PI_WIDEJUMP = 2;
-const uint8 PI_DIRECT = 4;
-const uint8 PI_SWITCH = 8;
-const uint8 PI_CANWIDE = 16;
+const U_8 PI_JUMP = 1;
+const U_8 PI_WIDEJUMP = 2;
+const U_8 PI_DIRECT = 4;
+const U_8 PI_SWITCH = 8;
+const U_8 PI_CANWIDE = 16;
 
 struct ParseInfo {
-    uint8 instr_min_len;   // length of the instruction with operands
-    uint8 flags;           // union of appropriate masks, see above 
+    U_8 instr_min_len;   // length of the instruction with operands
+    U_8 flags;           // union of appropriate masks, see above 
 };
 
 

Modified: harmony/enhanced/drlvm/trunk/vm/vmcore/src/verifier-3363/base/tpool.h
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/vmcore/src/verifier-3363/base/tpool.h?rev=660520&r1=660519&r2=660520&view=diff
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/vmcore/src/verifier-3363/base/ver_utils.h (original)
+++ harmony/enhanced/drlvm/trunk/vm/vmcore/src/verifier-3363/base/ver_utils.h Tue May 27 07:05:55 2008
@@ -224,7 +224,7 @@
     MemoryPageHead *static_page;
     MemoryPageHead *current_page;
 
-    uint8           static_mem[STATICSZ + sizeof (MemoryPageHead) ];
+    U_8           static_mem[STATICSZ + sizeof (MemoryPageHead) ];
 
     size_t  page_size;
     size_t  used;
@@ -272,7 +272,7 @@
             page_size = current_page->size;
         }
 
-        void *ret = (uint8*)current_page + sizeof(MemoryPageHead) + used;
+        void *ret = (U_8*)current_page + sizeof(MemoryPageHead) + used;
         used += sz;
         return ret;
     }
@@ -284,7 +284,7 @@
     }
 
     void dealloc_last(void* ptr, size_t sz) {
-        assert( ((uint8*)ptr) + sz == (uint8*)current_page + sizeof(MemoryPageHead) + used );
+        assert( ((U_8*)ptr) + sz == (U_8*)current_page + sizeof(MemoryPageHead) + used );
         used -= sz;
     }
 };
@@ -430,7 +430,7 @@
             result += *(key+idx);
         }
 
-        uint8 *bres = (uint8*) &result;
+        U_8 *bres = (U_8*) &result;
 
         return (bres[0] + bres[1] + bres[2] + bres[3]) & HASH_MASK;
     } // vf_Hash::HashFunc( key )

Modified: harmony/enhanced/drlvm/trunk/vm/vmcore/src/verifier-3363/java5/instr_props_5.h
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/vmcore/src/verifier-3363/java5/instr_props_5.h?rev=660520&r1=660519&r2=660520&view=diff
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/vmcore/src/verifier-3363/java5/instr_props_5.h (original)
+++ harmony/enhanced/drlvm/trunk/vm/vmcore/src/verifier-3363/java5/instr_props_5.h Tue May 27 07:05:55 2008
@@ -24,7 +24,7 @@
 class InstrProps : public InstrPropsBase {
 private:
     //array of bit flags
-    uint8* packed_flags;
+    U_8* packed_flags;
 
     //returns flags for the instruction 'instr'. other bits are not necessary 0s
     int get_dirty_mask(Address instr) {
@@ -53,7 +53,7 @@
     //initializes the class. this function is invoked once per method - removes old data in initializes storages.
     void init(Memory &mem, int code_len) {
         InstrPropsBase::init(mem, code_len);
-        packed_flags = (uint8*)mem.calloc( ((code_len/4) & ~3) + 4);
+        packed_flags = (U_8*)mem.calloc( ((code_len/4) & ~3) + 4);
     }
 
     //pass1: 00 - new (or dead code), 01 - parsed, 10 - middle of instruction, 11 - 'special' parsed (special == has stackmap)

Modified: harmony/enhanced/drlvm/trunk/vm/vmcore/src/verifier-3363/java5/stackmap_5.h
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/vmcore/src/verifier-3363/java5/stackmap_5.h?rev=660520&r1=660519&r2=660520&view=diff
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/vmcore/src/verifier-3363/java5/stackmap_5.h (original)
+++ harmony/enhanced/drlvm/trunk/vm/vmcore/src/verifier-3363/java5/stackmap_5.h Tue May 27 07:05:55 2008
@@ -289,7 +289,7 @@
 struct SubroutineData {
     Address caller;         //first JSR instruction that called this subroutine
     short retCount;         //number of ret instructions for this subroutine
-    uint8  subrDataflowed;   // =1 if dataflow pass for the subroutine is over
+    U_8  subrDataflowed;   // =1 if dataflow pass for the subroutine is over
 };
 
 //Store various data for the given instruction. Possible data are: StackMap vector, WorkMap vector,

Modified: harmony/enhanced/drlvm/trunk/vm/vmcore/src/verifier-3363/java6/context_6.cpp
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/vmcore/src/verifier-3363/java6/context_6.cpp?rev=660520&r1=660519&r2=660520&view=diff
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/vmcore/src/verifier-3363/java6/context_6.cpp (original)
+++ harmony/enhanced/drlvm/trunk/vm/vmcore/src/verifier-3363/java6/context_6.cpp Tue May 27 07:05:55 2008
@@ -231,7 +231,7 @@
     for( unsigned entry = 0; entry < number_of_entries; entry++) {
         if( read_ptr + 1 > attribute_end ) return error(VF_ErrorStackmap, "corrupted StackMapTable");
 
-        uint8 frame_type = (*read_ptr++);
+        U_8 frame_type = (*read_ptr++);
         unsigned offset;
         if( frame_type <= 63 ) { // 0-63
             //same locals as previous, stack is empty. offset calculated from frame_type
@@ -385,7 +385,7 @@
         //more elemens than max_locals or max_stack
         if( idx >= space_available ) return error(VF_ErrorStackmap, "corrupted StackMapTable");
 
-        uint8 tag = *((*attr)++);
+        U_8 tag = *((*attr)++);
         switch (tag) {
             case ITEM_TOP:
                 element[idx++].const_val = SmConstant(SM_BOGUS);

Modified: harmony/enhanced/drlvm/trunk/vm/vmcore/src/verifier-3363/x_verifier/recompute.cpp
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/vmcore/src/verifier-3363/x_verifier/recompute.cpp?rev=660520&r1=660519&r2=660520&view=diff
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/vmcore/src/verifier-3363/x_verifier/recompute.cpp (original)
+++ harmony/enhanced/drlvm/trunk/vm/vmcore/src/verifier-3363/x_verifier/recompute.cpp Tue May 27 07:05:55 2008
@@ -23,7 +23,7 @@
  * Recomputes StackMapTable attribute.
  */
 vf_Result
-vf_recompute_stackmaptable(Method_Handle method, uint8** attrBytes, char** error,
+vf_recompute_stackmaptable(Method_Handle method, U_8** attrBytes, char** error,
                            void* trustedPairs )
 {
     Class_Handle klass = method_get_class(method);
@@ -95,21 +95,21 @@
     }
 
     if( written_stackmap ) {
-        written_stackmap[7] = (uint8) entryNo & 0xFF;
+        written_stackmap[7] = (U_8) entryNo & 0xFF;
         entryNo >>= 8;
 
-        written_stackmap[6] = (uint8) entryNo & 0xFF;
+        written_stackmap[6] = (U_8) entryNo & 0xFF;
         ////////////
-        written_stackmap[5] = (uint8) attrLen & 0xFF;
+        written_stackmap[5] = (U_8) attrLen & 0xFF;
         attrLen >>= 8;
 
-        written_stackmap[4] = (uint8) attrLen & 0xFF;
+        written_stackmap[4] = (U_8) attrLen & 0xFF;
         attrLen >>= 8;
 
-        written_stackmap[3] = (uint8) attrLen & 0xFF;
+        written_stackmap[3] = (U_8) attrLen & 0xFF;
         attrLen >>= 8;
 
-        written_stackmap[2] = (uint8) attrLen & 0xFF;
+        written_stackmap[2] = (U_8) attrLen & 0xFF;
     }
 
     return VF_OK;
--- harmony/enhanced/drlvm/trunk/vm/port/include/port_atomic.h (original)
+++ harmony/enhanced/drlvm/trunk/vm/port/include/port_atomic.h Tue May 27 07:05:55 2008
@@ -47,7 +47,7 @@
 #if defined(_IPF_) || defined(DOXYGEN)
 
 /**
 * The atomic compare and exchange operation on <code>uint8</code>.
 * The function compares the current value of the specified <i>data</i>
 * with the <i>comp</i> value and if they match, swaps the <i>data</i>
 * with the <i>value</i>.
@@ -56,8 +56,8 @@
 * @param[in] comp       - the value to compare with
 * @return The old value.
 */
-APR_DECLARE(uint8) port_atomic_cas8(volatile uint8 * data, 
-                                               uint8 value, uint8 comp);
+APR_DECLARE(U_8) port_atomic_cas8(volatile U_8 * data, 
+                                               U_8 value, U_8 comp);
 
 /**  
 * The atomic compare and exchange operation on uint16. 
@@ -101,7 +101,7 @@
 
 #elif defined(_WIN32) && !defined(_WIN64)
 
-PORT_INLINE uint8 port_atomic_cas8(volatile uint8 * data , uint8 value, uint8 comp) {
+PORT_INLINE U_8 port_atomic_cas8(volatile U_8 * data , U_8 value, U_8 comp) {
     __asm {
         mov al,  comp
         mov dl,  value
@@ -152,8 +152,8 @@
 #pragma intrinsic(_InterlockedCompareExchange16)
 #pragma intrinsic(_InterlockedCompareExchange64)
 
-PORT_INLINE uint8 port_atomic_cas8(volatile uint8 * data, 
-                                               uint8 value, uint8 comp);
+PORT_INLINE U_8 port_atomic_cas8(volatile U_8 * data, 
+                                               U_8 value, U_8 comp);
 
 PORT_INLINE uint16 port_atomic_cas16(volatile uint16 * data, 
                                                  uint16 value, uint16 comp)
@@ -173,7 +173,7 @@
 
 #elif defined (PLATFORM_POSIX)  
 
-PORT_INLINE uint8 port_atomic_cas8(volatile uint8 * data , uint8 value, uint8 comp) {
+PORT_INLINE U_8 port_atomic_cas8(volatile U_8 * data , U_8 value, U_8 comp) {
 #if defined(_IA32_) || defined(_EM64T_)
     __asm__ __volatile__(
         "lock cmpxchgb %1, (%2)"
@@ -47,7 +47,7 @@
 
 /**
-* The atomic compare and exchange operation on <code>uint8</code>.
+* The atomic compare and exchange operation on <code>U_8</code>.
 * The function compares the current value of the specified <i>data</i>
 * with the <i>comp</i> value and if they match, swaps the <i>data</i>

Modified: harmony/enhanced/drlvm/trunk/vm/port/src/atomic/linux_ipf/port_atomic_asm.asm
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/port/src/atomic/linux_ipf/port_atomic_asm.asm?rev=660520&r1=660519&r2=660520&view=diff
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/vmcore/src/verifier-3363/base/tpool.h (original)
+++ harmony/enhanced/drlvm/trunk/vm/vmcore/src/verifier-3363/base/tpool.h Tue May 27 07:05:55 2008
@@ -158,7 +158,7 @@
         return sm_get_const_existing("java/lang/Throwable", &const_throwable);
     }
 
     //return SmConstant (known verification type) corresponding to uint8[]
     //returned value is cached
     SmConstant sm_get_const_arrayref_of_bb() {
         return sm_get_const_existing("[B", &const_arrayref_of_bb);
@@ -208,7 +208,7 @@
 
     //return SmConstant represented array of specified type
     //the type is specified in the OP_NEWARRAY instruction. See the spec for possible types
-    SmConstant sm_get_const_arrayref(uint8 see_spec) {
+    SmConstant sm_get_const_arrayref(U_8 see_spec) {
         switch ( see_spec ) {
     case 4: //T_BOOLEAN
     case 8: //T_BYTE
@@ -158,7 +158,7 @@
     }
 
-    //return SmConstant (known verification type) corresponding to uint8[]
+    //return SmConstant (known verification type) corresponding to U_8[]
     //returned value is cached
     SmConstant sm_get_const_arrayref_of_bb() {

Modified: harmony/enhanced/drlvm/trunk/vm/vmcore/src/verifier-3363/base/ver_utils.h
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/vmcore/src/verifier-3363/base/ver_utils.h?rev=660520&r1=660519&r2=660520&view=diff
==============================================================================